@@ -36,13 +36,11 @@ hugo_build = function(local = FALSE) {
 }
 
 theme_flag = function(config = load_config()) {
-  a = NULL
-  if (!is.null(d <- getOption('blogdown.themesDir'))) a = c('--themesDir', d) else {
-    d = get_config('themesDir', 'themes', config)
-  }
+  d = getOption('blogdown.themesDir', get_config('themesDir', 'themes', config))
   t = list.files(d)
   t = if (length(t) > 0) t[1]
   t = get_config('theme', t, config)
+  a = c('--themesDir', d)
   if (length(t) == 1) a = c(a, '-t', t)
   a
 }
@@ -57,7 +55,7 @@ change_config = function(name, value) {
     r = sprintf('^%s\\s*:.+', name)
     v = if (!is.na(value)) paste(name, value, sep = ': ')
   }
-  i = grep(r, x)
+  i = grep(r, x, ignore.case = TRUE)
   if (length(i) > 1) stop("Duplicated configuration for '", name, "' in ", f)
   x0 = x
   if (length(i) == 1) {
@@ -93,6 +91,8 @@ change_config = function(name, value) {
 #'   full URL of the zip file in \code{theme}, in which case this argument is ignored.
 #' @param theme_example Whether to copy the example in the \file{exampleSite}
 #'   directory if it exists in the theme. Not all themes provide example sites.
+#' @param empty_dirs Whether to keep the empty directories generated by Hugo.
+#' @param to_yaml Whether to convert the metadata of all posts to YAML.
 #' @param serve Whether to start a local server to serve the site.
 #' @references The full list of Hugo commands: \url{https://gohugo.io/commands},
 #'   and themes: \url{http://themes.gohugo.io}.
@@ -104,7 +104,7 @@ change_config = function(name, value) {
 new_site = function(
   dir = '.', install_hugo = TRUE, format = 'toml', sample = TRUE,
   theme = 'yihui/hugo-lithium', hostname = 'github.com', theme_example = TRUE,
-  serve = interactive()
+  empty_dirs = FALSE, to_yaml = TRUE, serve = interactive()
 ) {
   files = grep('[.]Rproj$', list.files(dir), invert = TRUE, value = TRUE)
   files = setdiff(files, c('LICENSE', 'README', 'README.md'))
@@ -120,7 +120,7 @@ new_site = function(
   # remove Hugo's default archetype (I think draft: true is a confusing default)
   unlink(file.path('archetypes', 'default.md'))
   # remove empty dirs
-  for (d in list.dirs(recursive = FALSE)) bookdown:::clean_empty_dir(d)
+  if (!empty_dirs) for (d in list.dirs(recursive = FALSE)) bookdown:::clean_empty_dir(d)
   if (is.character(theme) && length(theme) == 1 && !is.na(theme))
     install_theme(theme, theme_example, hostname = hostname)
   # remove the .gitignore that ignores everything under static/:
@@ -139,6 +139,8 @@ new_site = function(
   }
   if (!file.exists('index.Rmd'))
     writeLines(c('---', 'site: blogdown:::blogdown_site', '---'), 'index.Rmd')
+
+  if (to_yaml) hugo_convert('YAML', unsafe = TRUE)
   if (serve) serve_site()
 }
 
@@ -219,7 +221,7 @@ install_theme = function(
 #' @export
 #' @describeIn hugo_cmd Create a new (R) Markdown file via \command{hugo new}
 #'   (e.g. a post or a page).
-new_content = function(path, kind = 'default', open = interactive()) {
+new_content = function(path, kind = '', open = interactive()) {
   if (missing(kind)) kind = default_kind(path)
   path2 = with_ext(path, '.md')
   file  = content_file(path)
@@ -233,9 +235,9 @@ new_content = function(path, kind = 'default', open = interactive()) {
 
 default_kind = function(path) {
   path = normalizePath(path, '/', mustWork = FALSE)
-  if (!grepl('/', path)) return('default')
+  if (!grepl('/', path)) return('')
   atype = gsub('/.*', '.md', path)
-  if (!file.exists(file.path('archetypes', atype))) return('default')
+  if (!file.exists(file.path('archetypes', atype))) return('')
   gsub('/.*', '', path)
 }
 
@@ -288,7 +290,7 @@ content_file = function(path) file.path(get_config('contentDir', 'content'), pat
 #'   Similarly, you can set \code{options(blogdown.author = 'Your Name')} so
 #'   that the author field is automatically filled out when creating a new post.
 new_post = function(
-  title, kind = 'default', open = interactive(), author = getOption('blogdown.author'),
+  title, kind = '', open = interactive(), author = getOption('blogdown.author'),
   categories = NULL, tags = NULL, date = Sys.Date(), file = NULL, slug = NULL,
   title_case = getOption('blogdown.title_case'),
   subdir = getOption('blogdown.subdir', 'post'), ext = getOption('blogdown.ext', '.md')
